DeviceInfoUtil class

Constructors

DeviceInfoUtil()
factory

Properties

androidSdkInt → int
no setter
deviceInfo → String
no setter
deviceType → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
osVersion → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String
no setter

Methods

init() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
winUniqueIdentifier() → Future<String>
A unique device identifier.

Operators

operator ==(Object other) → bool
The equality operator.
inherited